#
# spec file for package python-spotipy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-spotipy
Version:        2.10.0
Release:        bp156.3.1
Summary:        Client for the Spotify Web API
License:        MIT
Group:          Development/Languages/Python
URL:            https://spotipy.readthedocs.org/
# https://github.com/plamere/spotipy/issues/454
Source:         https://github.com/plamere/spotipy/archive/%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 1.0
Requires:       python-six >= 1.10.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mock >= 2.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module six >= 1.10.0}
# /SECTION
%python_subpackages

%description
Spotipy is a Python library for the Spotify Web API.
With Spotipy, the user gets access to the music data
provided by the Spotify platform.

Documentation is available at
https://spotipy.readthedocs.io/

%prep
%setup -q -n spotipy-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/unit/

%files %{python_files}
%license LICENSE.md
%doc CHANGELOG.md
%{python_sitelib}/*

%changelog
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.10.0
  * Support for add_to_queue
  * Add CHANGELOG and LICENSE to released package
* Tue Mar 17 2020 pgajdos@suse.com
- version update to 2.9.0
  * Support `position_ms` optional parameter in `start_playback`
  * Add `requests_timeout` parameter to authentication methods
  * Make cache optional in `get_access_token`
  * Support for `playlist_cover_image`
  * Support `after` and `before` parameter in `current_user_recently_played`
  * CI for unit tests
  * Automatic `token` refresh
  * `auth_manager` and `oauth_manager` optional parameters added to `Spotify`'s init.
  * Optional `username` parameter to be passed to `SpotifyOAuth`, to infer a `cache_path` automatically
  * Optional `as_dict` parameter to control `SpotifyOAuth`'s `get_access_token` output type. However, this is going to be deprecated in the future, and the method will always return a token string
  * Optional `show_dialog` parameter to be passed to `SpotifyOAuth`
  * Both `SpotifyClientCredentials` and `SpotifyOAuth` inherit from a common `SpotifyAuthBase` which handles common parameters and logics.
  * Support for `playlist_tracks`
  * Support for `playlist_upload_cover_image`
  * `user_playlist_tracks` doesn't require a user anymore (accepts `None`)
  * Deprecated `user_playlist` and `user_playlist_tracks`
  * Fixed broken examples in README, examples and doc
  * Allow session keepalive
  * Bump requests to 2.20.0
  * Fixed inconsistent behaviour with some API methods when
  a full HTTP URL is passed.
  * Fixed invalid calls to logging warn method
  * Support for `playlist` to get a playlist without specifying a user
  * Support for `current_user_saved_albums_delete`
  * Support for `current_user_saved_albums_contains`
  * Support for `user_unfollow_artists`
  * Support for `user_unfollow_users`
  * Added follow and player endpoints
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Wed Dec 19 2018 Matej Cepl <mcepl@suse.com>
- Fix description and summary
* Wed Oct 17 2018 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 2.4.4)
